@@ -56,6 +56,21 @@ class SimplePropertiesTests(unittest.TestCase):
         )
         self.assertEqual(Graph().eccentricity(), [])
 
+    def testWeightedEccentricity(self):
+        self.assertEqual(
+            self.gfull.eccentricity(weights=[2] * self.gfull.ecount()),
+            [2] * self.gfull.vcount()
+        )
+        self.assertEqual(
+            self.gempty.eccentricity(weights=[]),
+            [0] * self.gempty.vcount()
+        )
+        self.assertEqual(
+            self.g.eccentricity(weights=range(1, self.g.ecount() + 1)),
+            [4, 5, 6, 6]
+        )
+        self.assertEqual(Graph().eccentricity(), [])
+
     def testRadius(self):
         self.assertEqual(self.gfull.radius(), 1)
         self.assertEqual(self.gempty.radius(), 0)
@@ -64,6 +79,12 @@ class SimplePropertiesTests(unittest.TestCase):
         self.assertEqual(self.tree.radius(), 3)
         self.assertTrue(isnan(Graph().radius()))
 
+    def testWeightedRadius(self):
+        self.assertEqual(self.gfull.radius(weights=[2] * self.gfull.ecount()), 2)
+        self.assertEqual(self.gempty.radius(weights=[]), 0)
+        self.assertEqual(self.g.radius(weights=range(1, self.g.ecount() + 1)), 4)
+        self.assertTrue(isnan(Graph().radius()))
+
     def testTransitivity(self):
         self.assertTrue(self.gfull.transitivity_undirected() == 1.0)
         self.assertTrue(self.tree.transitivity_undirected() == 0.0)
@@ -786,6 +807,18 @@ class PathTests(unittest.TestCase):
             g.distances(weights="weight", target=[2, 3])
             == [row[2:4] for row in expected]
         )
+        self.assertTrue(
+            g.distances(weights="weight", target=[2, 3], algorithm="bellman_ford")
+            == [row[2:4] for row in expected]
+        )
+        self.assertTrue(
+            g.distances(weights="weight", target=[2, 3], algorithm="johnson")
+            == [row[2:4] for row in expected]
+        )
+        self.assertRaises(
+            ValueError, g.distances,
+            weights="weight", target=[2, 3], algorithm="johnson", mode="in"
+        )
 
     def testGetShortestPath(self):
         g = Graph(4, [(0, 1), (0, 2), (1, 3), (3, 2), (2, 1)], directed=True)
@@ -795,6 +828,14 @@ class PathTests(unittest.TestCase):
         self.assertRaises(ValueError, g.get_shortest_path, 0, 3, output="x")
         self.assertRaises(TypeError, g.get_shortest_path, 0)
 
+    def testGetShortestPathManualAlgorithmSelection(self):
+        g = Graph(4, [(0, 1), (0, 2), (1, 3), (3, 2), (2, 1)], directed=True)
+        g.es["weight"] = [1] * g.ecount()
+
+        self.assertEqual([0, 1, 3], g.get_shortest_path(0, 3, algorithm="bellman_ford"))
+        self.assertRaises(ValueError, g.get_shortest_path, 0, 3, algorithm="johnson")
+        self.assertRaises(ValueError, g.get_shortest_path, 0, 3, algorithm="johnson", mode="in")
+
     def testGetShortestPaths(self):
         g = Graph(4, [(0, 1), (0, 2), (1, 3), (3, 2), (2, 1)], directed=True)
         sps = g.get_shortest_paths(0)
